@@ -321,11 +321,16 @@ class DataclassesRenderer:
             query = child.fields[0]
             query_name = query.name
             query_result_type = f"{query.type}"
-            if (
-                query_result_type not in DEFAULT_MAPPING.keys()
-                and query_result_type not in self.custom_scalars.keys()
-            ):
-                query_result_type = f"{parsed_op.name}Data.{query.type}"
+            if query_result_type in DEFAULT_MAPPING.keys():
+                query_result_type = DEFAULT_MAPPING.get(
+                    query_result_type, query_result_type
+                )
+            elif query_result_type in self.custom_scalars.keys():
+                query_result_type = self.custom_scalars.get(
+                    query_result_type, query_result_type
+                )
+            else:
+                query_result_type = f"{parsed_op.name}Data.{query_result_type}"
             if query.nullable:
                 query_result_type = f"Optional[{query_result_type}]"
             if query.is_list:
